.. _output_api:

Output
======
.. autosummary::
    :toctree: generated/

    sasktran2.OutputIdeal

Base Objects
------------
.. autosummary::
    :toctree: generated/

    sasktran2.Output


Internal Objects
----------------
.. autosummary::
    :toctree: generated/

    sasktran2.OutputIdealStokes_1
    sasktran2.OutputIdealStokes_3
